@@ -4,7 +4,7 @@ from .dropout import *
 from .layers import *
 from .normalization import *
 from .quantizers import *
-from .softmax2 import *
+from .shiftmax import *
 from .vit import *
 from .depthwise_convolution import *
 from .convolution import *
