@@ -18,7 +18,7 @@ import numpy as np
 import tensorflow as tf
 import keras
 
-from .layers import deserialize_quant_object, Calibrable
+from .layers import deserialize_quant_object, Calibrable, CalibrableVariable
 from ..tensors import FixedPoint, MAX_BUFFER_BITWIDTH
 
 
@@ -81,6 +81,12 @@ class QuantizedGELU(Calibrable, keras.layers.Layer):
         self.out_quantizer = deserialize_quant_object(
             self.quant_config, "output_quantizer", False)
 
+        # Add objects that will store the shift values.
+        self.q_in_shift = CalibrableVariable()
+        self.q_b_shift = CalibrableVariable()
+        self.q_inter_shift = CalibrableVariable()
+        self.q_c_shift = CalibrableVariable()
+
     @property
     def _pol_coeff(self):
         """Return the coefficients of the degree 2 polynomial approximation to the erf function."""
@@ -107,13 +113,17 @@ class QuantizedGELU(Calibrable, keras.layers.Layer):
             ``S`` denotes the quantization scale.
         """
         # Align intermediate inputs before adding them
-        q_in, _ = q_in.align(q_b)
-        q_b, _ = q_b.align(q_in)
+        q_in, shift = q_in.align(q_b)
+        self.q_in_shift(shift)
+        q_b, shift = q_b.align(q_in)
+        self.q_b_shift(shift)
         q_inter = (q_in + q_b)**2 * q_a
 
         # Align intermediate results before adding them
-        q_inter, _ = q_inter.align(q_c)
-        q_c, _ = q_c.align(q_inter)
+        q_inter, shift = q_inter.align(q_c)
+        self.q_inter_shift(shift)
+        q_c, shift = q_c.align(q_inter)
+        self.q_c_shift(shift)
         return q_inter + q_c
 
     def i_erf(self, q_in):
