@@ -19,8 +19,8 @@ import tensorflow as tf
 
 from ..tensors import FixedPoint, MAX_BUFFER_BITWIDTH, round_log2, pow2
 from .reshaping import QuantizedReshape, QuantizedPermute
-from .softmax2 import softmax2, QuantizedSoftmax2
-from .layers import deserialize_quant_object, Calibrable
+from .shiftmax import shiftmax, QuantizedShiftmax
+from .layers import deserialize_quant_object, Calibrable, CalibrableVariable
 
 
 __all__ = ["Attention", "string_to_softmax", "QuantizedAttention"]
@@ -29,8 +29,8 @@ __all__ = ["Attention", "string_to_softmax", "QuantizedAttention"]
 def string_to_softmax(s):
     """
     Convert a string to a softmax function.
-    Available options are 'softmax' for standard softmax, 'softmax2' for
-    softmax2.
+    Available options are 'softmax' for standard softmax, 'shiftmax' for
+    shiftmax.
 
     Args:
         s (str): string to convert.
@@ -40,10 +40,10 @@ def string_to_softmax(s):
     """
     if s == "softmax":
         return tf.nn.softmax
-    if s == "softmax2":
-        return softmax2
+    if s in ("softmax2", "shiftmax"):
+        return shiftmax
 
-    raise NotImplementedError("softmax should be in ['softmax', 'softmax2']"
+    raise NotImplementedError("softmax should be in ['softmax', 'shiftmax']"
                               f" but received {s}.")
 
 
@@ -87,7 +87,7 @@ class Attention(keras.layers.Layer):
     Args:
 
         num_heads (int): the number of attention heads
-        softmax (str, optional): 'softmax' or 'softmax2'. Defaults to 'softmax'
+        softmax (str, optional): 'softmax' or 'shiftmax'. Defaults to 'softmax'
 
     """
 
@@ -136,10 +136,14 @@ class Attention(keras.layers.Layer):
 
     def get_config(self):
         config = super().get_config()
+        softmax = self.softmax
+        if self.softmax == 'softmax2':
+            # softmax2 is the legacy name, use shiftmax now
+            softmax = 'shiftmax'
         config.update(
             {
                 "num_heads": self.num_heads,
-                "softmax": self.softmax
+                "softmax": softmax
             }
         )
         return config
@@ -148,10 +152,10 @@ class Attention(keras.layers.Layer):
 @tf.keras.utils.register_keras_serializable()
 class QuantizedAttention(Calibrable, Attention):
 
-    def __init__(self, num_heads, softmax='softmax2', quant_config={}, **kwargs):
-        if softmax != 'softmax2':
+    def __init__(self, num_heads, softmax='shiftmax', quant_config={}, **kwargs):
+        if softmax != 'shiftmax':
             raise ValueError(
-                "Only softmax2 is supported for quantized attention")
+                "Only shiftmax is supported for quantized attention")
         super().__init__(num_heads=num_heads, softmax=softmax, **kwargs)
         self.quant_config = quant_config
 
@@ -160,11 +164,13 @@ class QuantizedAttention(Calibrable, Attention):
 
         # Override softmax operation
         softmax_quant_conf = self.quant_config.get("softmax", {})
-        self.softmax_op = QuantizedSoftmax2(
+        self.softmax_op = QuantizedShiftmax(
             quant_config=softmax_quant_conf, name="quantized_softmax")
         # Extract other quantization parameters
         self.buffer_bitwidth = self.quant_config.get(
             "buffer_bitwidth", MAX_BUFFER_BITWIDTH) - 1
+        # Add objects that will store the shift values.
+        self.values_shift = CalibrableVariable()
 
     def separate_heads(self, x):
         x = QuantizedReshape((-1, self.num_heads, self.dim))(x)
@@ -175,9 +181,12 @@ class QuantizedAttention(Calibrable, Attention):
             # If any of the inputs is not a FixedPoint, raise an error
             raise ValueError("QuantizedAttention only accepts FixedPoint inputs")
         # Separate 2D embeddings per head to obtain 3D inputs
+        # Note: values is allowed to be quantized per-axis, so it must be aligned
         query = self.separate_heads(inputs[0])
         key = self.separate_heads(inputs[1])
-        value = self.separate_heads(inputs[2])
+        value, vshift = inputs[2].promote(self.buffer_bitwidth).align()
+        self.values_shift(vshift)
+        value = self.separate_heads(value)
         # Promote query to avoid saturation
         query = query.promote(self.buffer_bitwidth)
         # Dot product query and key for each head and pairs of tokens
