@@ -20,7 +20,7 @@ from keras import layers, backend
 from keras.utils import conv_utils
 
 from .layers import deserialize_quant_object, Calibrable, CalibrableVariable
-from ..tensors import FixedPoint, MAX_BUFFER_BITWIDTH, floor_through, QFloat
+from ..tensors import FixedPoint, MAX_BUFFER_BITWIDTH, QFloat
 
 
 __all__ = ["PaddedConv2D", "QuantizedConv2D", "QuantizedConv2DTranspose"]
@@ -237,8 +237,9 @@ class QuantizedConv2DTranspose(Calibrable, layers.Conv2DTranspose):
 
         # Add objects that will store the shift values.
         self.input_shift = CalibrableVariable()
-        self.conv_shift = CalibrableVariable()
-        self.bias_shift = CalibrableVariable()
+        if self.use_bias:
+            self.conv_shift = CalibrableVariable()
+            self.bias_shift = CalibrableVariable()
 
     def call(self, inputs, training=None):
         # Raise an error if the inputs are not FixedPoint
@@ -291,10 +292,9 @@ class QuantizedConv2DTranspose(Calibrable, layers.Conv2DTranspose):
         kernel_values = tf.transpose(kernel.values, (0, 1, 3, 2))
 
         # Do convolution on values
-        conv_values = floor_through(
-            backend.conv2d_transpose(inputs.values, kernel_values, output_shape_tensor,
-                                     self.strides, self.padding, self.data_format,
-                                     self.dilation_rate))
+        conv_values = backend.conv2d_transpose(inputs.values, kernel_values, output_shape_tensor,
+                                               self.strides, self.padding, self.data_format,
+                                               self.dilation_rate)
 
         if isinstance(kernel, QFloat):
             # Multiply by the scale
