@@ -23,7 +23,7 @@ from keras import backend
 from keras.layers import DepthwiseConv2D
 
 from ..tensors import FixedPoint, MAX_BUFFER_BITWIDTH
-from .layers import deserialize_quant_object, Calibrable
+from .layers import deserialize_quant_object, Calibrable, CalibrableVariable
 
 
 __all__ = ["QuantizedDepthwiseConv2D"]
@@ -50,6 +50,12 @@ class QuantizedDepthwiseConv2D(Calibrable, DepthwiseConv2D):
         self.buffer_bitwidth = self.quant_config.get("buffer_bitwidth", MAX_BUFFER_BITWIDTH) - 1
         assert self.buffer_bitwidth > 0, "The buffer_bitwidth must be a strictly positive integer."
 
+        # Add objects that will store the shift values.
+        self.input_shift = CalibrableVariable()
+        if self.use_bias:
+            self.output_shift = CalibrableVariable()
+            self.bias_shift = CalibrableVariable()
+
     def call(self, inputs, training=None):
         # raise an error if the inputs are not FixedPoint or tf.Tensor
         if not isinstance(inputs, (FixedPoint, tf.Tensor)):
@@ -65,7 +71,8 @@ class QuantizedDepthwiseConv2D(Calibrable, DepthwiseConv2D):
             inputs = FixedPoint.quantize(inputs, 0, 8)
 
         # Promote inputs to avoid saturation, then align them
-        inputs, _ = inputs.promote(self.buffer_bitwidth).align()
+        inputs, shift = inputs.promote(self.buffer_bitwidth).align()
+        self.input_shift(shift)
 
         outputs = backend.depthwise_conv2d(
             inputs,
@@ -79,8 +86,10 @@ class QuantizedDepthwiseConv2D(Calibrable, DepthwiseConv2D):
             bias = self.bias_quantizer(self.bias, training)
 
             # Align intermediate outputs and biases before adding them
-            outputs, _ = outputs.align(bias)
-            bias, _ = bias.promote(self.buffer_bitwidth).align(outputs)
+            outputs, shift = outputs.align(bias)
+            self.output_shift(shift)
+            bias, shift = bias.promote(self.buffer_bitwidth).align(outputs)
+            self.bias_shift(shift)
             outputs = tf.add(outputs, bias)
 
         if self.out_quantizer is not None:
