@@ -18,7 +18,7 @@ import tensorflow as tf
 import keras
 from tensorflow.python.framework import ops
 
-from .layers import deserialize_quant_object, Calibrable
+from .layers import deserialize_quant_object, Calibrable, CalibrableVariable
 from ..tensors import FixedPoint, reciprocal_lut, MAX_BUFFER_BITWIDTH
 
 
@@ -133,8 +133,6 @@ class QuantizedLayerNormalization(Calibrable, LayerMadNormalization):
     def __init__(self, *args, quant_config={}, **kwargs):
         super().__init__(*args, **kwargs)
         self.quant_config = quant_config
-        self.buf_bits = self.quant_config.get(
-            "buffer_bitwidth", MAX_BUFFER_BITWIDTH) - 1
         self.out_quantizer = deserialize_quant_object(
             self.quant_config, "output_quantizer", False)
         self.buffer_bitwidth = self.quant_config.get(
@@ -149,6 +147,12 @@ class QuantizedLayerNormalization(Calibrable, LayerMadNormalization):
         self.mad_quantizer = deserialize_quant_object(
             self.quant_config, "mad_quantizer", True)
 
+        # Add objects that will store the shift values.
+        self.input_shift = CalibrableVariable()
+        self.x_rescaled_shift = CalibrableVariable()
+        self.beta_shift = CalibrableVariable()
+        self.output_shift = CalibrableVariable()
+
     def call(self, inputs, training=None):
         """The quantized version of the LayerNormalization with Integer-only operations.
 
@@ -166,16 +170,19 @@ class QuantizedLayerNormalization(Calibrable, LayerMadNormalization):
                               inputs. Receives {type(inputs)} inputs.")
 
         # Increase the value_bits of inputs to avoid saturation, then align them
-        inputs, _ = inputs.promote(self.buffer_bitwidth).align()
+        inputs, shift = inputs.promote(self.buffer_bitwidth).align()
+        self.input_shift(shift)
 
         # Compute the Mean of the inputs
         sum_x = tf.math.reduce_sum(inputs, self.axis, keepdims=True)
         # Approximate mean_x = sum_x / 2**mean_shift
-        mean_x = sum_x >> self.mean_shift
+        # We could apply the shift virtually, but at this stage it is ok to drop the precision
+        # on the mean as it does not change the accuracy of the operation and prevents
+        # the explosion of the frac_bits.
+        # From an hardware perspective, it will correspond to an unconditional right-shift.
+        mean_x = sum_x.shift(-self.mean_shift)
 
-        # Compute the Absolute Deviation (MAD), aligned inputs and mean before
-        inputs, _ = inputs.align(mean_x)
-        mean_x, _ = mean_x.align(inputs)
+        # Compute the Absolute Deviation (MAD)
         x_shifted = inputs - mean_x
         mad_sum = tf.math.reduce_sum(
             x_shifted.abs(), self.axis, keepdims=True, name="mad")
@@ -196,14 +203,17 @@ class QuantizedLayerNormalization(Calibrable, LayerMadNormalization):
         x_rescaled = x_shifted * mad_inv
 
         # Downscale to recover the initial fractional bits
-        x_rescaled, _ = x_rescaled.downscale(x_shifted.frac_bits, self.buffer_bitwidth)
+        x_rescaled, shift = x_rescaled.downscale(x_shifted.frac_bits, self.buffer_bitwidth)
+        self.x_rescaled_shift(shift)
 
         # Multiply by gamma
         outputs = x_rescaled * gamma
 
         # Before adding the bias, we need aligned results
-        outputs, _ = outputs.align(beta)
-        beta, _ = beta.promote(self.buffer_bitwidth).align(outputs)
+        outputs, shift = outputs.align(beta)
+        self.output_shift(shift)
+        beta, shift = beta.promote(self.buffer_bitwidth).align(outputs)
+        self.beta_shift(shift)
         outputs = tf.add(outputs, beta)
         outputs.values.set_shape(inputs.shape)
 
