@@ -28,7 +28,7 @@ from ..layers import (QuantizedDense, QuantizedLayerNormalization, QuantizedAddP
                       QuantizedGlobalAveragePooling2D, QuantizedExtractToken, Dequantizer,
                       Quantizer, QuantizedSeparableConv2D, QuantizedFlatten, QuantizedReciprocal,
                       FixedPointQuantizer, WeightQuantizer, QuantizedConv2DTranspose,
-                      QuantizedShiftmax)
+                      QuantizedShiftmax, QuantizedSeparableConv2DTranspose)
 
 # Mapper to match float layer with its quantized version
 CUSTOM_QLAYERS = {
@@ -40,7 +40,8 @@ CUSTOM_QLAYERS = {
     'GlobalAveragePooling2D': QuantizedGlobalAveragePooling2D,
     "ExtractToken": QuantizedExtractToken, "SeparableConv2D": QuantizedSeparableConv2D,
     "Flatten": QuantizedFlatten, "Reciprocal": QuantizedReciprocal, "PaddedConv2D": QuantizedConv2D,
-    "Conv2DTranspose": QuantizedConv2DTranspose, "Shiftmax": QuantizedShiftmax
+    "Conv2DTranspose": QuantizedConv2DTranspose, "Shiftmax": QuantizedShiftmax,
+    "SeparableConv2DTranspose": QuantizedSeparableConv2DTranspose
 }
 # List of Quantizer layer's that do not have a float layer representation
 NO_FLOAT_CUSTOM_QLAYERS = [Dequantizer, FixedPointQuantizer, WeightQuantizer]
