@@ -20,7 +20,7 @@ import keras
 from typing import List, Union
 
 from ..debugging import assert_rank_at_least
-from .qtensor import QTensor, floor_through
+from .qtensor import QTensor
 from .fixed_point import FixedPoint
 from .qfloat import QFloat
 
@@ -174,9 +174,7 @@ def fp_matmul(a: FixedPoint,
         b_frac_bits = b.scales.frac_bits
 
     # Do matmul on values
-    m_values = floor_through(
-        tf.matmul(a.values, b.values, transpose_a, transpose_b, adjoint_a,
-                  adjoint_b, name))
+    m_values = tf.matmul(a.values, b.values, transpose_a, transpose_b, adjoint_a, adjoint_b, name)
     if isinstance(b, QFloat):
         # Multiply by the scales
         m_values *= b.scales.values
@@ -272,6 +270,30 @@ def fp_concat(values: List[FixedPoint], axis, name="concat"):
             values[0].value_bits, values[1].value_bits))
 
 
+@tf.experimental.dispatch_for_api(tf.expand_dims)
+def fp_expand_dims(input: FixedPoint, axis, name=None):
+    """Returns a tensor with a length 1 axis inserted at index `axis`.
+
+    Args:
+        input (FixedPoint): a `Tensor`.
+        axis (int): integer specifying the dimension index at which to expand the shape of `input`.
+            Given an input of D dimensions, `axis` must be in range `[-(D+1), D]` (inclusive).
+        name (str, optional): name of the output `Tensor`. Defaults to None.
+
+    Returns:
+        FixedPoint: a tensor with the same data as `input`, with an additional dimension inserted at
+            the index specified by `axis`.
+    """
+    # Only support per-tensor inputs
+    input.assert_per_tensor()
+
+    # Expand dimension on values
+    values = tf.expand_dims(input.values, axis, name)
+
+    # Return a new FixedPoint
+    return FixedPoint(values, input.frac_bits, input.value_bits)
+
+
 @tf.experimental.dispatch_for_api(tf.math.reduce_max)
 def fp_reduce_max(input_tensor: FixedPoint,
                   axis=None,
@@ -361,9 +383,8 @@ def fp_depthwise_conv2d(x: FixedPoint,
         filters_frac_bits = depthwise_kernel.scales.frac_bits
 
     # Do convolution on values
-    conv_values = floor_through(
-        keras.backend.depthwise_conv2d(x.values, depthwise_kernel.values, strides, padding,
-                                       data_format, dilation_rate))
+    conv_values = keras.backend.depthwise_conv2d(x.values, depthwise_kernel.values, strides,
+                                                 padding, data_format, dilation_rate)
     if isinstance(depthwise_kernel, QFloat):
         # Multiply by the scales
         conv_values *= depthwise_kernel.scales.values
@@ -407,9 +428,8 @@ def fp_convolution(
         filters_frac_bits = filters.scales.frac_bits
 
     # Do convolution on values
-    conv_values = floor_through(
-        tf.nn.convolution(input.values, filters.values, strides, padding, data_format,
-                          dilations, name))
+    conv_values = tf.nn.convolution(input.values, filters.values, strides, padding, data_format,
+                                    dilations, name)
     if isinstance(filters, QFloat):
         # Multiply by the scales
         conv_values *= filters.scales.values
